==> react-native-digitcamera-1.11.2.tgz: package/src/Screens/AnimationEaseLinear.js <==
import React, { forwardRef, useEffect, useMemo, useReducer, useState } from "react";
import {
  Animated,
  Easing,
  StyleSheet,
  View,
  Image,
  Dimensions,
  FlatList,
} from "react-native";
import Colors from "../common/Colors";
import {
  ANIM_DURATION,
  ANIMATION_TRACK,
  zIndex_moving_thumbnail,
  OBJ_WIDTH,
} from "./StencilAnimation";
// const pi_pose_strip = require("../../images/pi_pose_strip.png");
import {
  SCREEN_HEIGHT,
  SCREEN_WIDTH,
} from "react-native-digitcamera/src/common/Constants";
const pi_pose_strip = {
  uri: "https://d2h44aw7l5xdvz.cloudfront.net/CRM/PRM/car_angles-01.png",
};
const car_ech = require("../../src/common/Image/car_ech.png");
const car_chp = require("../../src/common/Image/car_chp.png");
const car_wnd = require("../../src/common/Image/car_wnd.png");
const car_fs = require("../../src/common/Image/car_fs.png");
const car_flc = require("../../src/common/Image/car_flc.png");
const car_ls = require("../../src/common/Image/car_ls.png");
const car_blc = require("../../src/common/Image/car_blc.png");
const car_bs = require("../../src/common/Image/car_bs.png");
const car_brc = require("../../src/common/Image/car_brc.png");
const car_rs = require("../../src/common/Image/car_rs.png");
const car_frc = require("../../src/common/Image/car_frc.png");
const car_dbd = require("../../src/common/Image/car_dbd.png");

var xData = [
  { source: car_ech, key: "1", focus: true },
  { source: car_chp, key: "2", focus: false },
  { source: car_fs, key: "3", focus: false },
  { source: car_flc, key: "4", focus: false },
  { source: car_ls, key: "5", focus: false },
  { source: car_blc, key: "6", focus: false },
  { source: car_bs, key: "7", focus: false },
  { source: car_brc, key: "8", focus: false },
  { source: car_rs, key: "9", focus: false },
  { source: car_frc, key: "10", focus: false },
  { source: car_wnd, key: "11", focus: false },
  { source: car_dbd, key: "12", focus: false },
];

export const getStridesArr = (instruction) =>{
  var strideArr = [];
  const instructionObj = JSON.parse(instruction);
  const videoObj = instructionObj.find((item)=>item?.type=="video");
  if(videoObj){
    const videoInstructionArr = videoObj?.TSurveyInstructions;
    if(videoInstructionArr){
      const strideObjArr = videoInstructionArr?.filter((item)=>item?.type == "stride");
      if(strideObjArr){
        strideObjArr.map((item, index)=>{
          strideArr.push({source:item?.instructionAssests, key:""+index, focus: (index==0?true:false)})
        });
      }
    }
  }
  console.log("*** AnimationEaseLinear getStridesArr strideArr ", strideArr);
  return strideArr;
}

const AnimationEaseLinear = forwardRef((props, multiRef) => {
  const animFirst = new Animated.Value(0);
  const { mlCompleteRef, moveNextRef } = multiRef.current;
  const {instruction} = props;
  const [ref, setRef] = useState(null);
  const [data, setData] = useState(xData);
  const maxSize = Math.max(SCREEN_HEIGHT, SCREEN_WIDTH);

  const getStride = useMemo(()=>{
    const strideArr = getStridesArr(instruction);
    setData(strideArr);
  },[instruction])

  useEffect(() => {
    moveNextRef.current = moveToCheckNextPose;
  }, [ref]);

  const moveToCheckNextPose = (newPoseIndex) => {
    var focusIndex = newPoseIndex;
    console.log(
      "**** AnimationEaseLinear moveToCheckNextPose focusIndex : " + focusIndex
    );
    if (ref) {
      if (focusIndex > data.length - 1) {
        focusIndex = 0;
        if (mlCompleteRef.current) {
          mlCompleteRef.current(false); // Calls stopScreenRecordingCallback from StencilAnimatin
        }
      }
      ref.scrollToIndex({
        animated: true,
        index: focusIndex,
        viewPosition: 0,
      });
      const newData = data.map((item, index) => {
        if (focusIndex === index) {
          return { ...item, focus: true };
        } else {
          return { ...item, focus: false };
        }
      });
      setData(newData);
    }
  };

  const renderItem = ({ item, index }) => {
    const img = item?.source.includes("http") ? {uri:item?.source} : item?.source;
    return (
      <View style={{ width: OBJ_WIDTH }}>
        {item.focus && (
          <View
            style={{
              position: "absolute",
              backgroundColor: Colors.digitYellow,
              height: 5,
              width: "100%",
              borderBottomLeftRadius: 10,
              borderBottomRightRadius: 10,
            }}
          />
        )}
        <Image
          style={{ width: OBJ_WIDTH, height: "100%", marginHorizontal: 2 }}
          source={img}
          resizeMode="center"
        />
      </View>
    );
  };

  return (
    <View style={[styles.mainView, { width: maxSize }]}>
      <FlatList
        style={{ width: maxSize }}
        horizontal={true}
        data={data}
        ref={(ref) => {
          setRef(ref);
        }}
        renderItem={renderItem}
        // ItemSeparatorComponent={Divider}
        keyExtractor={(itemData) => itemData.key}
      />
      {/* <Animated.View
        style={[styles.animView, { transform: [{ translateX: animFirst }] }]}
      /> */}
    </View>
  );
});

const styles = StyleSheet.create({
  mainView: {
    flex: 1,
    height: "15%",
    zIndex: 1000,
    marginTop: 0,
    width: "100%",
    position: "absolute",
    top: 0,
    justifyContent: "flex-start",
    backgroundColor: "black",
  },
  animView: {
    height: "100%",
    borderWidth: 2,
    borderColor: Colors.digitYellow,
    borderRadius: 5,
    width: "10%",
    backgroundColor: "transparent",
    position: "absolute",
  },
  stencilStyle: {
    width: "100%",
    height: "100%",
  },
  poseImage: {
    width: "100%",
    height: "100%",
    backgroundColor: "white",
  },
});

export default AnimationEaseLinear;

==> react-native-digitcamera-1.13.0.tgz: package/src/Screens/AnimationEaseLinear.js <==
import React, { forwardRef, useEffect, useMemo, useReducer, useState } from "react";
import {
  Animated,
  Easing,
  StyleSheet,
  View,
  Image,
  Dimensions,
  FlatList,
} from "react-native";
import Colors from "../common/Colors";
import {
  ANIM_DURATION,
  ANIMATION_TRACK,
  zIndex_moving_thumbnail,
  OBJ_WIDTH,
} from "./StencilAnimation";
// const pi_pose_strip = require("../../images/pi_pose_strip.png");
import {
  SCREEN_HEIGHT,
  SCREEN_WIDTH,
} from "react-native-digitcamera/src/common/Constants";
const pi_pose_strip = {
  uri: "https://d2h44aw7l5xdvz.cloudfront.net/CRM/PRM/car_angles-01.png",
};
const car_ech = require("../../src/common/Image/car_ech.png");
const car_chp = require("../../src/common/Image/car_chp.png");
const car_wnd = require("../../src/common/Image/car_wnd.png");
const car_fs = require("../../src/common/Image/car_fs.png");
const car_flc = require("../../src/common/Image/car_flc.png");
const car_ls = require("../../src/common/Image/car_ls.png");
const car_blc = require("../../src/common/Image/car_blc.png");
const car_bs = require("../../src/common/Image/car_bs.png");
const car_brc = require("../../src/common/Image/car_brc.png");
const car_rs = require("../../src/common/Image/car_rs.png");
const car_frc = require("../../src/common/Image/car_frc.png");
const car_dbd = require("../../src/common/Image/car_dbd.png");

var xData = [
  { source: car_ech, key: "1", focus: true },
  { source: car_chp, key: "2", focus: false },
  { source: car_fs, key: "3", focus: false },
  { source: car_flc, key: "4", focus: false },
  { source: car_ls, key: "5", focus: false },
  { source: car_blc, key: "6", focus: false },
  { source: car_bs, key: "7", focus: false },
  { source: car_brc, key: "8", focus: false },
  { source: car_rs, key: "9", focus: false },
  { source: car_frc, key: "10", focus: false },
  { source: car_fs, key: "11", focus: false },
  { source: car_wnd, key: "12", focus: false },
  { source: car_dbd, key: "13", focus: false },
];

export const getStridesArr = (instruction) =>{
  var strideArr = [];
  const instructionObj = JSON.parse(instruction);
  const videoObj = instructionObj.find((item)=>item?.type=="video");
  if(videoObj){
    const videoInstructionArr = videoObj?.TSurveyInstructions;
    if(videoInstructionArr){
      const strideObjArr = videoInstructionArr?.filter((item)=>item?.type == "stride");
      if(strideObjArr){
        strideObjArr.map((item, index)=>{
          strideArr.push({source:item?.instructionAssests, key:""+index, focus: (index==0?true:false)})
        });
      }
    }
  }
  console.log("*** AnimationEaseLinear getStridesArr strideArr ", strideArr);
  if(strideArr && strideArr.length > 0){
    return strideArr;
  }else{
    return xData;
  }
}

const AnimationEaseLinear = forwardRef((props, multiRef) => {
  const animFirst = new Animated.Value(0);
  const { mlCompleteRef, moveNextRef } = multiRef.current;
  const {instruction} = props;
  const [ref, setRef] = useState(null);
  const [data, setData] = useState(xData);
  const maxSize = Math.max(SCREEN_HEIGHT, SCREEN_WIDTH);

  const getStride = useMemo(()=>{
    const strideArr = getStridesArr(instruction);
      setData(strideArr);
  },[instruction])

  useEffect(() => {
    moveNextRef.current = moveToCheckNextPose;
  }, [ref]);

  const moveToCheckNextPose = (newPoseIndex) => {
    var focusIndex = newPoseIndex;
    console.log(
      "**** AnimationEaseLinear moveToCheckNextPose focusIndex : " + focusIndex
    );
    if (ref && data && data.length > 0) {
      if (focusIndex > data.length - 1) {
        focusIndex = 0;
        if (mlCompleteRef.current) {
          mlCompleteRef.current(false); // Calls stopScreenRecordingCallback from StencilAnimatin
        }
      }
      ref.scrollToIndex({
        animated: true,
        index: focusIndex,
        viewPosition: 0,
      });
      const newData = data.map((item, index) => {
        if (focusIndex === index) {
          return { ...item, focus: true };
        } else {
          return { ...item, focus: false };
        }
      });
      setData(newData);
    }
  };

  const renderItem = ({ item, index }) => {
    const img = item?.source && typeof (item?.source) == 'string'  && item?.source.includes("http") ? {uri:item?.source} : item?.source;
    return (
      <View style={{ width: OBJ_WIDTH }}>
        {item.focus && (
          <View
            style={{
              position: "absolute",
              backgroundColor: Colors.digitYellow,
              height: 5,
              width: "100%",
              borderBottomLeftRadius: 10,
              borderBottomRightRadius: 10,
            }}
          />
        )}
        <Image
          style={{ width: OBJ_WIDTH, height: "100%", marginHorizontal: 2 }}
          source={img}
          resizeMode="center"
        />
      </View>
    );
  };

  return (
    <View style={[styles.mainView, { width: maxSize }]}>
      <FlatList
        style={{ width: maxSize }}
        horizontal={true}
        data={data}
        ref={(ref) => {
          setRef(ref);
        }}
        renderItem={renderItem}
        // ItemSeparatorComponent={Divider}
        keyExtractor={(itemData) => itemData.key}
      />
      {/* <Animated.View
        style={[styles.animView, { transform: [{ translateX: animFirst }] }]}
      /> */}
    </View>
  );
});

const styles = StyleSheet.create({
  mainView: {
    flex: 1,
    height: "15%",
    zIndex: 1000,
    marginTop: 0,
    width: "100%",
    position: "absolute",
    top: 0,
    justifyContent: "flex-start",
    backgroundColor: "black",
  },
  animView: {
    height: "100%",
    borderWidth: 2,
    borderColor: Colors.digitYellow,
    borderRadius: 5,
    width: "10%",
    backgroundColor: "transparent",
    position: "absolute",
  },
  stencilStyle: {
    width: "100%",
    height: "100%",
  },
  poseImage: {
    width: "100%",
    height: "100%",
    backgroundColor: "white",
  },
});

export default AnimationEaseLinear;
